Title: [103426] trunk/Source/WebCore
Revision
103426
Author
[email protected]
Date
2011-12-21 11:52:57 -0800 (Wed, 21 Dec 2011)

Log Message

ScrollingCoordinator functions should take FrameView objects
https://bugs.webkit.org/show_bug.cgi?id=75023

Reviewed by Sam Weinig.

* page/ScrollingCoordinator.cpp:
(WebCore::ScrollingCoordinator::syncFrameViewGeometry):
* page/ScrollingCoordinator.h:
* page/mac/ScrollingCoordinatorMac.mm:
(WebCore::ScrollingCoordinator::setFrameViewScrollLayer):
* rendering/RenderLayerCompositor.cpp:
(WebCore::RenderLayerCompositor::frameViewDidChangeSize):
(WebCore::RenderLayerCompositor::updateRootLayerPosition):
(WebCore::RenderLayerCompositor::ensureRootLayer):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (103425 => 103426)


--- trunk/Source/WebCore/ChangeLog	2011-12-21 19:52:08 UTC (rev 103425)
+++ trunk/Source/WebCore/ChangeLog	2011-12-21 19:52:57 UTC (rev 103426)
@@ -1,5 +1,22 @@
 2011-12-21  Anders Carlsson  <[email protected]>
 
+        ScrollingCoordinator functions should take FrameView objects
+        https://bugs.webkit.org/show_bug.cgi?id=75023
+
+        Reviewed by Sam Weinig.
+
+        * page/ScrollingCoordinator.cpp:
+        (WebCore::ScrollingCoordinator::syncFrameViewGeometry):
+        * page/ScrollingCoordinator.h:
+        * page/mac/ScrollingCoordinatorMac.mm:
+        (WebCore::ScrollingCoordinator::setFrameViewScrollLayer):
+        * rendering/RenderLayerCompositor.cpp:
+        (WebCore::RenderLayerCompositor::frameViewDidChangeSize):
+        (WebCore::RenderLayerCompositor::updateRootLayerPosition):
+        (WebCore::RenderLayerCompositor::ensureRootLayer):
+
+2011-12-21  Anders Carlsson  <[email protected]>
+
         Get rid of ScrollableAreaClient
         https://bugs.webkit.org/show_bug.cgi?id=75021
 

Modified: trunk/Source/WebCore/page/ScrollingCoordinator.cpp (103425 => 103426)


--- trunk/Source/WebCore/page/ScrollingCoordinator.cpp	2011-12-21 19:52:08 UTC (rev 103425)
+++ trunk/Source/WebCore/page/ScrollingCoordinator.cpp	2011-12-21 19:52:57 UTC (rev 103426)
@@ -62,16 +62,16 @@
     m_page = 0;
 }
 
-void ScrollingCoordinator::syncFrameGeometry(Frame* frame)
+void ScrollingCoordinator::syncFrameViewGeometry(FrameView* frameView)
 {
     ASSERT(isMainThread());
     ASSERT(m_page);
 
-    if (frame != m_page->mainFrame())
+    if (frameView->frame() != m_page->mainFrame())
         return;
 
-    IntRect visibleContentRect = frame->view()->visibleContentRect();
-    IntSize contentsSize = frame->view()->contentsSize();
+    IntRect visibleContentRect = frameView->visibleContentRect();
+    IntSize contentsSize = frameView->contentsSize();
 
     MutexLocker locker(m_mainFrameGeometryMutex);
     if (m_mainFrameVisibleContentRect == visibleContentRect && m_mainFrameContentsSize == contentsSize)

Modified: trunk/Source/WebCore/page/ScrollingCoordinator.h (103425 => 103426)


--- trunk/Source/WebCore/page/mac/ScrollingCoordinatorMac.mm	2011-12-21 19:52:08 UTC (rev 103425)
+++ trunk/Source/WebCore/page/mac/ScrollingCoordinatorMac.mm	2011-12-21 19:52:57 UTC (rev 103426)
@@ -29,6 +29,7 @@
 
 #import "ScrollingCoordinator.h"
 
+#import "FrameView.h"
 #import "Page.h"
 #import <QuartzCore/QuartzCore.h>
 #import <wtf/Functional.h>
@@ -160,12 +161,12 @@
     return scrollingThread;
 }
 
-void ScrollingCoordinator::setFrameScrollLayer(Frame* frame, const GraphicsLayer* scrollLayer)
+void ScrollingCoordinator::setFrameViewScrollLayer(FrameView* frameView, const GraphicsLayer* scrollLayer)
 {
     ASSERT(isMainThread());
     ASSERT(m_page);
 
-    if (frame != m_page->mainFrame())
+    if (frameView->frame() != m_page->mainFrame())
         return;
 
     MutexLocker locker(m_mainFrameGeometryMutex);

Modified: trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp (103425 => 103426)


--- trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2011-12-21 19:52:08 UTC (rev 103425)
+++ trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2011-12-21 19:52:57 UTC (rev 103426)
@@ -973,7 +973,7 @@
 
 #if ENABLE(THREADED_SCROLLING)
         if (ScrollingCoordinator* scrollingCoordinator = this->scrollingCoordinator())
-            scrollingCoordinator->syncFrameGeometry(frameView->frame());
+            scrollingCoordinator->syncFrameViewGeometry(frameView);
 #endif
     }
 }
@@ -1231,7 +1231,7 @@
 
 #if ENABLE(THREADED_SCROLLING)
     if (ScrollingCoordinator* scrollingCoordinator = this->scrollingCoordinator())
-        scrollingCoordinator->syncFrameGeometry(m_renderView->frameView()->frame());
+        scrollingCoordinator->syncFrameViewGeometry(m_renderView->frameView());
 #endif
 }
 
@@ -1801,7 +1801,7 @@
 
 #if ENABLE(THREADED_SCROLLING)
             if (ScrollingCoordinator* scrollingCoordinator = this->scrollingCoordinator())
-                scrollingCoordinator->setFrameScrollLayer(m_renderView->frameView()->frame(), m_scrollLayer.get());
+                scrollingCoordinator->setFrameViewScrollLayer(m_renderView->frameView(), m_scrollLayer.get());
 #endif
         }
     } else {
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to
--- trunk/Source/WebCore/page/ScrollingCoordinator.h	2011-12-21 19:52:08 UTC (rev 103425)
+++ trunk/Source/WebCore/page/ScrollingCoordinator.h	2011-12-21 19:52:57 UTC (rev 103426)
@@ -40,7 +40,7 @@
 
 namespace WebCore {
 
-class Frame;
+class FrameView;
 class GraphicsLayer;
 class Page;
 class PlatformWheelEvent;
@@ -56,12 +56,12 @@
 
     void pageDestroyed();
 
-    // Should be called whenever the scroll layer for the given frame changes.
-    void setFrameScrollLayer(Frame*, const GraphicsLayer* scrollLayer);
+    // Should be called whenever the scroll layer for the given frame view changes.
+    void setFrameViewScrollLayer(FrameView*, const GraphicsLayer* scrollLayer);
 
     // Should be called whenever the geometry of the given frame changes,
     // including the visible content rect and the content size.
-    void syncFrameGeometry(Frame*);
+    void syncFrameViewGeometry(FrameView*);
 
     // Can be called from any thread. Will try to handle the wheel event on the scrolling thread,
     // and return false if the event must be sent again to the WebCore event handler.
@@ -56,12 +56,12 @@
 
-    // Should be called whenever the geometry of the given frame changes,
+    // Should be called whenever the geometry of the given frame view changes,
     // including the visible content rect and the content size.

Modified: trunk/Source/WebCore/page/mac/ScrollingCoordinatorMac.mm (103425 => 103426)

